@@ -47,18 +47,18 @@ abstract methods :meth:`~ae.gui_app.MainAppBase.init_app` and
 
 For to activate the help mode the widget
 for to display the help texts have to be assigned to
-the attribute :attr:`~HelpAppBase.help_layout::
+the attribute :attr:`~HelpAppBase.ae_help_layout::
 
-    main_app.help_layout = HelpScreenContainerOrWindow()
+    main_app.ae_help_layout = HelpScreenContainerOrWindow()
 
-So :attr:`~HelpAppBase.help_layout is also used as a flag
+So :attr:`~HelpAppBase.ae_help_layout is also used as a flag
 of the help mode activity. By assigning `None` to this
 attribute the help mode will be deactivated::
 
-    main_app.help_layout = None
+    main_app.ae_help_layout = None
 
 Optionally you can use the attribute
-:attr:`~HelpAppBase.help_activator` for
+:attr:`~HelpAppBase.ae_help_activator` for
 to store a widget that allows the user
 to toggle the help mode activation. The
 :meth:`~HelpAppBase.help_display` is using
@@ -206,7 +206,7 @@ from ae.i18n import default_language, get_f_string, translation
 from ae.gui_app import FLOW_KEY_SEP, id_of_flow, MainAppBase                    # type: ignore
 
 
-__version__ = '0.0.3'
+__version__ = '0.0.4'
 
 
 IGNORED_HELP_FLOWS = (id_of_flow('close', 'flow_popup'), )  #: tuple of flow ids never search/show help text for
@@ -321,9 +321,9 @@ class HelpAppBase(MainAppBase, ABC):
     """ main app help base class. """
 
     # additional instance attributes
-    help_activator: Any = None          #: help flow mode de-/activator button widget
-    help_id: str = ''                   #: help message id of the currently explained target widget
-    help_layout: Optional[Any] = None   #: container/popup/dropdown/window widget in active help flow mode else None
+    ae_help_activator: Any = None           #: help flow mode de-/activator button widget
+    ae_help_id: str = ''                    #: message id of the currently explained/focused target widget in help mode
+    ae_help_layout: Optional[Any] = None    #: container/popup/dropdown/window widget in active help flow mode else None
 
     @abstractmethod
     def ensure_top_most_z_index(self, widget: Any):
@@ -395,14 +395,14 @@ class HelpAppBase(MainAppBase, ABC):
         :return:                return value for caller (:meth:`~ae.gui_app.MainAppBase.change_flow`) which is
                                 True if help layout is active and got updated, else False.
         """
-        hlw = self.help_layout
+        hlw = self.ae_help_layout
         if hlw is None:
             return changed              # inactive help layout
 
         widget = None
         state_name = help_vars['state_name']
         help_id = self.help_app_state_id(state_name)
-        if help_id == self.help_id:
+        if help_id == self.ae_help_id:
             if not changed:
                 return False            # allow to execute app state change
         else:
@@ -435,10 +435,10 @@ class HelpAppBase(MainAppBase, ABC):
         :param key_suffix:      suffix to the key used if the translation is a dict.
         :param must_have:       pass True for to display error help text and console output if no help text exists.
         """
-        hlw: Any = self.help_layout
-        hlw.widget = widget or self.help_activator
+        hlw: Any = self.ae_help_layout
+        hlw.widget = widget or self.ae_help_activator
 
-        self.change_observable('help_id', help_id)
+        self.change_observable('ae_help_id', help_id)
 
         has_trans = translation(help_id)
         if not has_trans and FLOW_KEY_SEP in help_id:
@@ -470,7 +470,7 @@ class HelpAppBase(MainAppBase, ABC):
         :return:                return value for caller (:meth:`~ae.gui_app.MainAppBase.change_flow`) which is
                                 True if help layout is active and got updated, else False.
         """
-        hlw = self.help_layout
+        hlw = self.ae_help_layout
         if hlw is None:
             return changed              # inactive help layout
 
@@ -479,7 +479,7 @@ class HelpAppBase(MainAppBase, ABC):
             return changed
 
         help_id = self.help_flow_id(nfi)
-        if help_id == self.help_id:
+        if help_id == self.ae_help_id:
             if not changed:
                 return False            # allow to execute flow change of currently explained flow button
             widget = hlw.widget
